==> gpt_readme-0.0.1.tar.gz: gpt_readme-0.0.1/gpt_readme/prompts.py <==
# written in chinese
SYSTEM_PROMPT = """
你是一个经验丰富的{language}程序员，你的工作是要解释总结代码模块或者代码文件.你的总结将被其他程序员和被使用者阅读, 并用你的总结来学习这部分代码模块或者代码文件. 你需要保持严谨, 诚实, 不能生成不存在或者错误的描述来误导他人.
请注意, 你是一个严谨的代码工程师, 要完成文档撰写的需求. 不要回复除了代码文档总结外其余无关的内容.
最重要的是, 阅读你的文档的人使用的语言是'{human_language}', 你必须按照'{human_language}'语言生成你的回复!
"""

MODULE_PROMPT = """
如下是{language}模块的注释和代码, 这个模块相对于整个代码库的代码路径是{path}, 你需要理解, 总结并推理这个模块的功能. 
### 这个模块包含如下的文件, 每个文件对应的注释也包含在其中. 文件内容用[]包裹起来, 如果内容为空则说明模块不包含任何文件:
[{file_summaries}]

### 这个模块包含如下的子模块, 每个子模块对应的注释也包含在其中. 子模块内容用[]包裹起来, 如果内容为空则说明模块不包含任何子模块:
[{module_summaries}]

请你用Markdown格式写下这个模块的总结. 根据上述提供的注释, 将这个模块分成如下几个章节进行总结:
Introduction: 你需要在这个章节提供一个简单的介绍, 介绍这个模块的作用, 以及这个模块的主要功能.
Features: 你需要在这个章节总结这个模块里不同功能对应的文件以及子模块. 如果你发现这个模块并没有注释或者代码输入的话, 则忽视这个章节的总结

请你精简你的专业总结
"""

FILE_PROMPT = """
如下是{language}文件的代码, 文件相对于整个代码库的代码路径是{path}, 你需要理解, 总结并推理这个文件的功能. 
这个文件包含如下的代码:
```
{code}
```
请你用Markdown格式写下这个文件的总结. 根据上述提供的注释, 将这个文件分成如下几个章节进行总结:
Introduction: 你需要在这个章节提供一个简单的介绍, 介绍这个文件实现的功能, 在整个代码库中可能存在的作用, 以及他可能被使用的场景
Features: 你需要在这个章节总结这个文件实现的功能与它的类, 变量, 函数之间的关系. 如果你发现这个文件并没有代码输入的话, 则忽视这个章节的总结

请你精简你的专业总结, 并尽量控制在{max_length}个字符以内.
"""

FILE_NEXT_PROMPT = """
你现在正在逐步理解总结一个{language}文件的代码, 文件相对于整个代码库的代码路径是{path}. 你需要最终推理这个文件的功能. 

你之前已经理解总结过的内容有:
[{before_summary}]
你当前正在理解总结的代码:
```
{code}
```

请你用Markdown格式写下这个文件的总结. 根据上述提供的注释, 将这个文件分成如下几个章节进行总结:
Introduction: 你需要在这个章节提供一个简单的介绍, 介绍这个文件实现的功能, 以及他可能被使用的场景
Features: 你需要在这个章节总结这个文件实现的功能与它的类, 变量, 函数之间的关系. 

请你精简你的专业总结, 并尽量控制在{max_length}个字符以内.
"""

FINAL_PROMPT = """
如下是一整个{language}代码库的解释, 这个模块的代码路径是{path}:
[{module_summaries}]

你需要理解, 总结这个模块的功能, 并且生成一个容易理解, 专业的README文档. 
请你用Markdown格式写下这个模块的README. 根据上述提供的信息, 你需要首先强调出这个模块的名字, 然后将这个模块分成如下几个章节进行总结:

Introduction: 你需要在这个章节提供一个简单的介绍, 介绍这个模块的作用, 以及这个模块的主要功能.
Get Started: 你需要在这个章节, 根据上述信息提供安装介绍, 正确明朗的告诉用户如何安装这个模块, 请根据模块所使用的代码语言和提供的信息, 提供正确的安装指令.
Features: 你需要在这个章节总结这个模块里不同功能对应的文件以及子模块. 你需要根据子模块和文件的描述, 提供代码所在位置和功能的总结. 如果你发现这个模块并没有注释或者代码输入的话, 则忽视这个章节的总结
Acknowledgement: 你需要在这个章节总结这个模块用到的第三方代码库, 并且分别介绍他们的功能. 在这个章节的最后表示你的感谢
"""

==> gpt_readme-0.0.2.tar.gz: gpt_readme-0.0.2/gpt_readme/prompts.py <==
# written in chinese
SYSTEM_PROMPT = """
你是一个经验丰富的{language}程序员，你的工作是要解释总结代码模块或者代码文件.你的总结将被其他程序员和被使用者阅读, 并用你的总结来学习这部分代码模块或者代码文件. 你需要保持严谨, 诚实, 不能生成不存在或者错误的描述来误导他人.
请注意, 你是一个严谨的代码工程师, 要完成文档撰写的需求. 不要回复除了代码文档总结外其余无关的内容.
最重要的是, 阅读你的文档的人使用的语言是'{human_language}', 你必须按照'{human_language}'语言生成你的回复!
"""

MODULE_PROMPT = """
如下是{language}模块的子模块和代码文件的Markdown文档, 这个模块相对于整个代码库的代码路径是{path}, 你需要理解, 总结并推理这个模块的功能. 

这个模块包含如下的文件, 每个文件对应的注释也包含在其中. 文件内容用[]包裹起来, 如果内容为空则说明模块不包含任何文件:
[{file_summaries}]
---
### 这个模块包含如下的子模块, 每个子模块对应的注释也包含在其中. 子模块内容用[]包裹起来, 如果内容为空则说明模块不包含任何子模块:
[{module_summaries}]
---
请你用Markdown格式写下这个模块的总结. 根据上述提供的注释, 将这个模块分成如下几个章节进行总结:
Introduction: 你需要在这个章节提供一个简单的介绍, 介绍这个模块的作用, 以及这个模块的主要功能.
Features: 你需要在这个章节总结这个模块里不同功能对应的文件以及子模块. 如果你发现这个模块并没有注释或者代码输入的话, 则忽视这个章节的总结
Command-line Usage: 请你一步步观察发现子模块和代码文件的描述中是否含有命令行参数指令来指使如何使用这个代码库. 如果有的话, 请你在这个章节的总结中列举出正确的命令行使用方法, 以及正确的命令行参数选项有哪些. 否则不需要生成这一章节

请你精简你的专业总结
"""

FILE_PROMPT = """
如下是{language}文件的代码, 文件相对于整个代码库的代码路径是{path}, 你需要理解, 总结并推理这个文件的功能. 
这个文件包含如下的代码:
```
{code}
```
请你用Markdown格式写下这个文件的总结. 根据上述提供的注释, 将这个文件分成如下几个章节进行总结:
Introduction: 你需要在这个章节提供一个简单的介绍, 介绍这个文件实现的功能, 在整个代码库中可能存在的作用, 以及他可能被使用的场景
Features: 你需要在这个章节总结这个文件实现的功能与它的类, 变量, 函数之间的关系. 如果你发现这个文件并没有代码输入的话, 则忽视这个章节的总结
Command-line Usage: 如果你发现这个代码文件是含有命令行参数指令. 请你在这个文件的总结中列举出正确的命令行使用方法, 以及正确的命令行参数选项有哪些. 如果只是包含函数, 类等代码逻辑的话, 这不需要生成这一章节

请你精简你的专业总结, 并尽量控制在{max_length}个字符以内.
"""

FINAL_PROMPT = """
如下是一整个{language}代码库的解释, 这个模块的代码路径是{path}:
[{module_summaries}]

你需要理解, 总结这个模块的功能, 并且生成一个容易理解, 专业的README文档. 
请你用Markdown格式写下这个模块的README. 根据上述提供的信息, 你需要首先强调出这个模块的名字, 然后将这个模块分成如下几个章节进行总结:

Introduction: 你需要在这个章节提供一个简单的介绍, 介绍这个模块的作用, 以及这个模块的主要功能.
Get Started: 你需要在这个章节, 根据上述信息提供安装和使用介绍, 正确明朗的告诉用户如何安装这个模块.然后根据模块所使用的代码语言和提供的信息, 提供正确的命令行参数来使用这个模块, 展示正确的代码接口.
Features: 你需要在这个章节总结这个模块里不同功能对应的文件以及子模块. 你需要根据子模块和文件的描述, 提供代码所在位置和功能的总结. 如果你发现这个模块并没有注释或者代码输入的话, 则忽视这个章节的总结
Acknowledgement: 你需要在这个章节总结这个模块用到的第三方代码库, 并且分别介绍他们的功能. 在这个章节的最后表示你的感谢

此外, 在不改变整体总结架构的情况下, 你需要满足如下的需求:
{user_demand}
"""

# FILE_NEXT_PROMPT = """
# 你现在正在逐步理解总结一个{language}文件的代码, 文件相对于整个代码库的代码路径是{path}. 你需要最终推理这个文件的功能.

# 你之前已经理解总结过的内容有:
# [{before_summary}]
# 你当前正在理解总结的代码:
# ```
# {code}
# ```

# 请你用Markdown格式写下这个文件的总结. 根据上述提供的注释, 将这个文件分成如下几个章节进行总结:
# Introduction: 你需要在这个章节提供一个简单的介绍, 介绍这个文件实现的功能, 以及他可能被使用的场景
# Features: 你需要在这个章节总结这个文件实现的功能与它的类, 变量, 函数之间的关系.

# 请你精简你的专业总结, 并尽量控制在{max_length}个字符以内.
# """
